Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(111)

Unified Diff: sdk/lib/developer/developer.dart

Issue 1271693003: Change `msg` to `message` in debugger function. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Also fix signatures in dart2js patch file. Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/js_runtime/lib/developer_patch.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/developer/developer.dart
diff --git a/sdk/lib/developer/developer.dart b/sdk/lib/developer/developer.dart
index 06c980e7e929f833b7d6997e137103d7ddac3ef4..b7f2376bad7fcff3987fe161bc3811306f599b9b 100644
--- a/sdk/lib/developer/developer.dart
+++ b/sdk/lib/developer/developer.dart
@@ -19,22 +19,22 @@ part 'profiler.dart';
/// If [when] is true, stop the program as if a breakpoint were hit at the
/// following statement.
///
/// Returns the value of [when]. Some debuggers may
/// display [msg].
///
/// NOTE: When invoked, the isolate will not return until a debugger
/// continues execution. When running in the Dart VM the behaviour is the same
/// regardless of whether or not a debugger is connected. When compiled to
/// JavaScript, this uses the "debugger" statement, and behaves exactly as
/// that does.
-external bool debugger({bool when: true, String msg});
+external bool debugger({bool when: true, String message});
/// Send a reference to [object] to any attached debuggers.
///
/// Debuggers may open an inspector on the object. Returns the argument.
-external inspect(object);
+external Object inspect(Object object);
/// Emit a log event.
+///
/// [sequenceNumber] is a monotonically increasing sequence number.
/// [millisececondsSinceEpoch] is a timestamp.
/// [level] is the severity level (value between 0 and 2000 inclusive).
@@ -19,22 +19,22 @@ part 'profiler.dart';
/// following statement.
///
-/// Returns the value of [when]. Some debuggers may
-/// display [msg].
+/// Returns the value of [when]. Some debuggers may display [message].
///
/// NOTE: When invoked, the isolate will not return until a debugger
« no previous file with comments | « sdk/lib/_internal/js_runtime/lib/developer_patch.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698